==> apache-camel-3.11.5-src.zip: apache-camel-3.11.5/components/camel-http/src/test/java/org/apache/camel/component/http/handler/DrinkAuthValidationHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.http.handler;

import java.io.IOException;

import org.apache.http.HttpException;
import org.apache.http.HttpRequest;
import org.apache.http.HttpResponse;
import org.apache.http.protocol.HttpContext;
import org.junit.jupiter.api.Assertions;

public class DrinkAuthValidationHandler extends DrinkValidationHandler {

    public DrinkAuthValidationHandler(String expectedMethod, String expectedQuery, Object expectedContent, String header) {
        super(expectedMethod, expectedQuery, expectedContent, header);
    }

    @Override
    public void handle(HttpRequest request, HttpResponse response, HttpContext context) throws HttpException, IOException {
        String auth = request.getFirstHeader("Authorization").getValue();
        Assertions.assertTrue(auth.startsWith("Basic"));
        super.handle(request, response, context);
    }
}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-http/src/test/java/org/apache/camel/component/http/handler/DrinkAuthValidationHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.http.handler;

import java.io.IOException;

import org.apache.hc.core5.http.ClassicHttpRequest;
import org.apache.hc.core5.http.ClassicHttpResponse;
import org.apache.hc.core5.http.Header;
import org.apache.hc.core5.http.HttpException;
import org.apache.hc.core5.http.HttpHeaders;
import org.apache.hc.core5.http.protocol.HttpContext;
import org.junit.jupiter.api.Assertions;

public class DrinkAuthValidationHandler extends DrinkValidationHandler {

    public DrinkAuthValidationHandler(String expectedMethod, String expectedQuery, Object expectedContent, String header) {
        super(expectedMethod, expectedQuery, expectedContent, header);
    }

    @Override
    public void handle(ClassicHttpRequest request, ClassicHttpResponse response, HttpContext context)
            throws HttpException, IOException {
        Header authorization = request.getFirstHeader(HttpHeaders.AUTHORIZATION);
        Assertions.assertNotNull(authorization);
        String auth = authorization.getValue();
        Assertions.assertTrue(auth.startsWith("Basic"));
        super.handle(request, response, context);
    }
}
